.. yar_numerals documentation master file, created by
   sphinx-quickstart on Tue Jul 11 00:11:57 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Yar. Numerals. Documentation for the Python implementation!
===========================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:


.. automodule:: yar_numerals
   :members:

.. automodule:: yar_numerals.errors
   :members:

.. automodule:: yar_numerals.grammar
   :members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
